@@ -6,7 +6,7 @@ use Test2::API qw/test2_add_callback_exit context/;
 use Path::Tiny qw/path/;
 use Carp qw/croak/;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 our %FILES;
 
@@ -16,15 +16,23 @@ XSLoader::load(__PACKAGE__, $VERSION);
 my $IMPORTED = 0;
 sub import {
     my $class = shift;
-    my @params = @_;
+    my %params = @_;
+
+    return if $params{no_event};
 
     if ($IMPORTED++) {
-        croak "$class has already been imported, too late to add params" if @params;
+        croak "$class has already been imported, too late to add params" if keys %params;
         return;
     }
 
+    my $ran = 0;
     my $root = path('.')->realpath;
-    test2_add_callback_exit(sub { $class->report(@params, ctx => $_[0], root => $root) });
+    my $callback = sub { return if $ran++; $class->report(%params, ctx => $_[0], root => $root) };
+
+    test2_add_callback_exit($callback);
+
+    # Fallback if we fork.
+    eval 'END { local $?; $callback->() }; 1' or die $@;
 }
 
 sub clear { %FILES = () }
@@ -164,19 +172,23 @@ The following data was gathered using prove to run the full L<Moose> test suite:
     # Prove on its own
     Files=478, Tests=17326, 64 wallclock secs ( 1.62 usr  0.46 sys + 57.27 cusr  4.92 csys = 64.27 CPU)
 
-    # Prove with Test2::Plugin::Cover
-    Files=478, Tests=17326, 71 wallclock secs ( 1.73 usr  0.40 sys + 64.22 cusr  6.02 csys = 72.37 CPU)
+    # Prove with Test2::Plugin::Cover (no coverage event)
+    Files=478, Tests=17326, 67 wallclock secs ( 1.61 usr  0.46 sys + 60.98 cusr  5.31 csys = 68.36 CPU)
 
     # Prove with Devel::Cover
     Files=478, Tests=17324, 963 wallclock secs ( 2.39 usr  0.58 sys + 929.12 cusr 31.98 csys = 964.07 CPU)
 
+I<no coverage event> - No report was generated. This was done to only measure
+the effect of the XS that adds the data collection overhead, and not the cost
+of the perl code that generates the report event at the end of every test.
+
 The L<Moose> test suite was also run using L<Test2::Harness> aka C<yath>
 
     # Without Test2::Plugin::Cover
     Wall Time: 62.51 seconds CPU Time: 69.13 seconds (usr: 1.84s | sys: 0.08s | cusr: 60.77s | csys: 6.44s)
 
-    # With Test2::Plugin::Cover
-    Wall Time: 79.32 seconds CPU Time: 86.19 seconds (usr: 2.07s | sys: 0.04s | cusr: 76.02s | csys: 8.06s)
+    # With Test2::Plugin::Cover (no coverage event)
+    Wall Time: 75.46 seconds CPU Time: 82.00 seconds (usr: 1.96s | sys: 0.05s | cusr: 72.64s | csys: 7.35s)
 
 As you can see, there is a performance hit, but it is fairly small, specially
 compared to L<Devel::Cover>. This is not to say anything bad about
@@ -203,6 +215,19 @@ You can tell prove to use the module this way:
 This also works for L<Test2::Harness> aka C<yath>, but yath may have a flag to
 enable this for you by the time you are reading these docs.
 
+=head2 SUPPRESS REPORT
+
+You can suppess the final report (only collect data, do not send the Test2
+event)
+
+CLI:
+
+    HARNESS_PERL_SWITCHES=-MTest2::Plugin::Cover=no_event,1 prove ...
+
+INLINE:
+
+    use Test2::Plugin::Cover no_event => 1;
+
 =head1 CLASS METHODS
 
 =over 4
